@@ -113,7 +113,8 @@ class Assessment(AnyEntity):
 
     def dc_title(self):
         if self.datetime:
-            return '%s (%s)' % (self._cw._('Assessment'), self.datetime)
+            return '%s (%s)' % (self._cw._('Assessment'),
+                                self._cw.format_date(self.datetime))
         return self._cw._('Assessment')
 
 
@@ -148,7 +149,7 @@ class ScoreValue(AnyEntity):
         _def_title = self._cw._(_def.dc_title())
         title = u'%s : %s' % (_def_title, self.complete_value)
         if self.datetime:
-            title += ' (%s)' % self.datetime
+            title += ' (%s)' % self._cw.format_date(self.datetime)
         return title
 
     @property
@@ -250,9 +251,9 @@ class Admission(AnyEntity):
         title = '%s %s' % (self._cw._('Admission'), self.admission_in[0].dc_title())
         dates = []
         if self.admission_date:
-            dates.append(ustrftime(self.admission_date, '%Y,%m,%d'))
+            dates.append(self._cw.format_date(self.admission_date))
         if self.admission_end_date:
-            dates.append(ustrftime(self.admission_end_date, '%Y,%m,%d'))
+            dates.append(self._cw.format_date(self.admission_end_date))
         if dates:
             title += ' (%s)' % '/'.join(dates)
         return title
@@ -264,7 +265,7 @@ class AdmissionStep(AnyEntity):
     def dc_title(self):
         title = self.name
         if self.step_date:
-            title += ' (%s)' % self.step_date
+            title += ' (%s)' % self._cw.format_date(self.step_date)
         return title
 
 def registration_callback(vreg):
