@@ -34,11 +34,10 @@ class Subject(EntityType):
                         indexed=True, maxsize=64)
     surname = String(fulltextindexed=True, maxsize=256)
     firstname = String(fulltextindexed=True, maxsize=256)
-    gender = String(required=True, indexed=True,
-                    vocabulary=('male', 'female', 'unknown'))
+    gender = String(indexed=True, vocabulary=('male', 'female', 'unknown'))
     date_of_birth = Date()
-    handedness = String(required=True, indexed=True,
-                        vocabulary=('right', 'left', 'ambidextrous', 'mixed', 'unknown'))
+    handedness = String(indexed=True, vocabulary=('right', 'left',
+                                                  'ambidextrous', 'mixed', 'unknown'))
     related_studies = SubjectRelation('Study', cardinality='**')
     related_groups = SubjectRelation('SubjectGroup', cardinality='**')
     related_infos = SubjectRelation('ScoreValue', cardinality='**')
@@ -48,6 +47,13 @@ class Subject(EntityType):
     related_therapies = SubjectRelation('Therapy', cardinality='**', composite='subject')
 
 
+class SurvivalData(EntityType):
+    """ Survival data for patients"""
+    deceased = Boolean()
+    relapse_date = Date()
+    survival_of = SubjectRelation('Subject', cardinality='1*', inlined=True, composite='object')
+
+
 class Study(EntityType):
     """ The project """
     name = String(required=True, indexed=True, maxsize=256)
@@ -76,6 +82,8 @@ class Admission(EntityType):
     admission_date = Date(description=_('Date of admission of the patient in the study'))
     admission_end_date = Date(description=_('Date when the patient leaves the study'),
                               constraints=[BoundaryConstraint('>=', Attribute('admission_date'))])
+    subject_age = Int(description=_('Subject age at admission')) # in years
+    subject_admission_number = String(fulltextindexed=True)
     admission_of = SubjectRelation('Subject', cardinality='1*', composite='object', inlined=True)
     admission_in = SubjectRelation('Study', cardinality='1*', inlined=True)
     description = RichString(fulltextindexed=True, description=_('Additional admission infos'))
@@ -183,7 +191,7 @@ class Diagnostic(EntityType):
     leads_to_therapies = SubjectRelation('Therapy', cardinality='**')
     technical_analysis = SubjectRelation('TechnicalAnalysis', cardinality='**')
     based_on = SubjectRelation('GenericMeasure', cardinality='**')
-
+    disease_side = String(vocabulary=('left', 'right', 'both'),)
 
 class TechnicalAnalysis(EntityType):
     """ Analysis attributes and links.
@@ -206,6 +214,7 @@ class Therapy(EntityType):
     relevant_anomaly = String(maxsize=1024)
     therapy_for = SubjectRelation('Disease', cardinality='**')
     based_on_diagnostic = SubjectRelation('Diagnostic', cardinality='**')
+    related_study = SubjectRelation('Study', cardinality='?*', inlined=True)
     description = RichString(fulltextindexed=True)
 
 class DrugTake(EntityType):
