@@ -17,9 +17,9 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """cubicweb-medicalexp views/forms/actions/components for web ui"""
-from cubicweb.web import facet
-from cubicweb.selectors import is_instance
 
+from cubicweb.web import facet
+from cubicweb.predicates import is_instance
 
 class SubjectGenderFacet(facet.AttributeFacet):
     __regid__ = 'subject-gender-facet'
@@ -37,15 +37,6 @@ class SubjectHandednessFacet(facet.AttributeFacet):
     title = _('Handedness')
 
 
-class SubjectAgeFacet(facet.RangeFacet):
-    __regid__ = 'subject-age-facet'
-    __select__ = facet.RangeFacet.__select__ & is_instance('Subject')
-    path = ['X concerned_by S', 'S age_of_subject A']
-    order = 3
-    filter_variable = 'A'
-    title = _('Age')
-
-
 class SubjectStudyFacet(facet.RelationFacet):
     __regid__ = 'subject-study-facet'
     __select__ = facet.RelationFacet.__select__ & is_instance('Subject')
@@ -91,6 +82,7 @@ class DrugTakeDrug(facet.RelationFacet):
     rtype = 'drug'
     target_attr = 'name'
     title = _('drug')
+    order = 2
 
 
 class DrugStartDateFacet(facet.DateRangeFacet):
@@ -98,13 +90,15 @@ class DrugStartDateFacet(facet.DateRangeFacet):
     __select__ = is_instance('DrugTake')
     rtype = 'start_taking_date'
     title = _('start_taking_date')
+    order = 7
 
 
 class DrugStopDateFacet(facet.DateRangeFacet):
     __regid__ = 'drugtake-stop-date'
     __select__ = is_instance('DrugTake')
-    rtype = 'stop__taking_date'
+    rtype = 'stop_taking_date'
     title = _('stop_taking_date')
+    order = 8
 
 
 class DrugTakeDosis(facet.RangeFacet):
@@ -112,6 +106,7 @@ class DrugTakeDosis(facet.RangeFacet):
     __select__ = facet.RangeFacet.__select__ & is_instance('DrugTake')
     rtype = 'dosis'
     title = _('dosis')
+    order = 4
 
 
 class DrugTakeNumberOfCycles(facet.RangeFacet):
@@ -119,6 +114,7 @@ class DrugTakeNumberOfCycles(facet.RangeFacet):
     __select__ = facet.RangeFacet.__select__ & is_instance('DrugTake')
     rtype = 'number_of_cycles'
     title = _('number_of_cycles')
+    order = 3
 
 
 class DrugTakeDosisPercentage(facet.RangeFacet):
@@ -126,6 +122,7 @@ class DrugTakeDosisPercentage(facet.RangeFacet):
     __select__ = facet.RangeFacet.__select__ & is_instance('DrugTake')
     rtype = 'dosis_percentage'
     title = _('dosis_percentage')
+    order = 5
 
 
 class DrugTakeUnits(facet.AttributeFacet):
@@ -133,6 +130,7 @@ class DrugTakeUnits(facet.AttributeFacet):
     __select__ = facet.RangeFacet.__select__ & is_instance('DrugTake')
     rtype = 'unit'
     title = _('unit')
+    order = 6
 
 
 class DrugTakeReducedDosis(facet.AttributeFacet):
@@ -140,6 +138,7 @@ class DrugTakeReducedDosis(facet.AttributeFacet):
     __select__ = facet.RangeFacet.__select__ & is_instance('DrugTake')
     rtype = 'reduced_dosis'
     title = _('reduced_dosis')
+    order = 9
 
 
 class DiagnosticDatetimeFacet(facet.DateRangeFacet):
